@@ -1,23 +1,9 @@
 /*
     This file is part of the Okteta Core library, made within the KDE community.
 
-    Copyright 2004,2011 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2004, 2011 Friedrich W. H. Kossebau <kossebau@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "decimalbytecodec.hpp"
@@ -32,6 +18,11 @@ Byte DecimalByteCodec::digitsFilledLimit() const { return 26; }
 
 void DecimalByteCodec::encode(QString* digits, unsigned int pos, Byte byte) const
 {
+    const int minSizeNeeded = pos + 3;
+    if (digits->size() < minSizeNeeded) {
+        digits->resize(minSizeNeeded);
+    }
+
     unsigned char digitValue = byte / 100;
     (*digits)[pos++] = QLatin1Char('0' + digitValue);
     byte -= digitValue * 100;
@@ -43,6 +34,12 @@ void DecimalByteCodec::encode(QString* digits, unsigned int pos, Byte byte) cons
 
 void DecimalByteCodec::encodeShort(QString* digits, unsigned int pos, Byte byte) const
 {
+    const int encodingLength = (byte > 99) ? 3 : (byte > 9) ? 2 : 1;
+    const int minSizeNeeded = pos + encodingLength;
+    if (digits->size() < minSizeNeeded) {
+        digits->resize(minSizeNeeded);
+    }
+
     const unsigned char firstDigitValue = byte / 100;
     if (firstDigitValue > 0) {
         (*digits)[pos++] = QLatin1Char('0' + firstDigitValue);
