@@ -34,7 +34,7 @@ encodingDataList[] =
     { ISO8859_6Encoding, "ISO-8859-6" },
     { ISO8859_7Encoding, "ISO-8859-7" },
     { ISO8859_8Encoding, "ISO-8859-8" },
-    { ISO8859_8_IEncoding, "ISO-8859-8-I" },
+//     { ISO8859_8_IEncoding, "ISO-8859-8-I" }, Qt (at least 5.15) delivers this variant already for ISO-8859-8
     { ISO8859_9Encoding, "ISO-8859-9" },
     { ISO8859_10Encoding, "ISO-8859-10" },
     { ISO8859_11Encoding, "TIS-620" }, // was: ISO-8859-11
