@@ -24,9 +24,12 @@ class ReplacePieceTableChange : public AbstractPieceTableChange
 public:
     ReplacePieceTableChange(const AddressRange& removeRange, Size insertLength, Address storageOffset,
                             const PieceList& removedPieces);
+    ReplacePieceTableChange(const ReplacePieceTableChange&) = delete;
 
     ~ReplacePieceTableChange() override;
 
+    ReplacePieceTableChange& operator=(const ReplacePieceTableChange&) = delete;
+
 public: // AbstractPieceTableChange API
     int type() const override;
     QString description() const override;
