@@ -10,8 +10,6 @@
 #include "abstractbytearrayview_p.hpp"
 
 // lib
-#include "controller/abstractcontroller.hpp"
-#include "controller/abstractwheelcontroller.hpp"
 #include "bytearraytablelayout.hpp"
 
 namespace Okteta {
@@ -561,9 +559,7 @@ void AbstractByteArrayView::focusOutEvent(QFocusEvent* focusEvent)
 void AbstractByteArrayView::keyPressEvent(QKeyEvent* keyEvent)
 {
     Q_D(AbstractByteArrayView);
-    if (!d->controller()->handleKeyPress(keyEvent)) {
-        ColumnsView::keyPressEvent(keyEvent);
-    }
+    d->keyPressEvent(keyEvent);
 }
 
 void AbstractByteArrayView::mousePressEvent(QMouseEvent* mouseEvent)
@@ -594,9 +590,7 @@ void AbstractByteArrayView::mouseDoubleClickEvent(QMouseEvent* mouseEvent)
 void AbstractByteArrayView::wheelEvent(QWheelEvent* wheelEvent)
 {
     Q_D(AbstractByteArrayView);
-    if (!d->wheelController()->handleWheelEvent(wheelEvent)) {
-        ColumnsView::wheelEvent(wheelEvent);
-    }
+    d->wheelEvent(wheelEvent);
 }
 
 void AbstractByteArrayView::dragEnterEvent(QDragEnterEvent* dragEnterEvent)
