@@ -26,12 +26,16 @@
 #include "cursor.hpp"
 #include "bordercolumnrenderer.hpp"
 #include "oktetagui.hpp"
+// liboktetawidgets
+#include <bytearraychar8stringdecoder.hpp>
+#include <bytearrayvaluestringdecoder.hpp>
 // Okteta core
 #include <Okteta/ValueCodec>
 #include <Okteta/Bookmarkable>
 #include <Okteta/Versionable>
 #include <Okteta/TextByteArrayAnalyzer>
 #include <Okteta/Bookmark>
+#include <Okteta/Character>
 // Qt
 #include <QScroller>
 #include <QPainter>
@@ -759,12 +763,62 @@ QByteArray AbstractByteArrayViewPrivate::selectedData() const
 
 QMimeData* AbstractByteArrayViewPrivate::selectionAsMimeData() const
 {
+    Q_Q(const AbstractByteArrayView);
+
     if (!mTableRanges->hasSelection()) {
         return nullptr;
     }
 
+    const QByteArray bytes = selectedData();
+
     auto* mimeData = new QMimeData;
-    mimeData->setData(octetStreamFormatName(), selectedData());
+    mimeData->setData(octetStreamFormatName(), bytes);
+
+    QString displayedText;
+    if (activeCoding() == AbstractByteArrayView::CharCodingId) {
+        const QChar undefinedChar = q->undefinedChar();
+        const QChar substituteChar = q->substituteChar();
+
+        const Okteta::CharCodec* const charCodec = this->charCodec();
+        const QChar tabChar = QLatin1Char('\t');
+        const QChar returnChar = QLatin1Char('\n');
+
+        displayedText.reserve(bytes.size());
+
+        for (const auto byte : bytes) {
+            const Okteta::Character byteChar = charCodec->decode(byte);
+
+            const QChar streamChar = byteChar.isUndefined() ?      undefinedChar :
+                                     (!byteChar.isPrint()
+                                      || byteChar == tabChar
+                                      || byteChar == returnChar) ? substituteChar :
+                                                                   static_cast<QChar>(byteChar);
+            displayedText.append(streamChar);
+        }
+    } else {
+        // prepare
+        QString valueString;
+        valueString.resize(mValueCodec->encodingWidth());
+
+        const QChar separator = QLatin1Char(' ');
+        const int separatorSize = 1;
+        displayedText.reserve((valueString.size() + separatorSize) * bytes.size() - separatorSize);
+
+        bool isFirst = true;
+        for (const auto byte : bytes) {
+            if (Q_LIKELY(!isFirst)) {
+                displayedText.append(separator);
+            } else {
+                isFirst = false;
+            }
+
+            mValueCodec->encode(&valueString, 0, byte);
+
+            displayedText.append(valueString);
+        }
+    }
+    mimeData->setText(displayedText);
+
     return mimeData;
 }
 
@@ -818,18 +872,43 @@ void AbstractByteArrayViewPrivate::pasteData(const QMimeData* data)
     }
 
     // SYNC: with bytearraydocumentfactory.cpp
-    // if there is a octet stream, use it, otherwise take the dump of the format
-    // with the highest priority
-    // TODO: this may not be, what is expected, think about it, if we just
-    // take byte array descriptions, like encodings in chars or values
+    // If there is an octet stream, use it, otherwise  try to decode values or chars,
+    // assuming byte array descriptions by text.
+    // If that fails, take the dump of the format with the highest priority.
+    // TODO: instead of guessing, ask user for the decoding to try.
     // would need the movement of the encoders into the core library
-    QString dataFormatName = octetStreamFormatName();
-    if (!data->hasFormat(dataFormatName)) {
-        dataFormatName = data->formats()[0];
+    QByteArray byteArray;
+    const QString dataFormatName = octetStreamFormatName();
+    if (data->hasFormat(dataFormatName)) {
+        byteArray = data->data(dataFormatName);
+    } else {
+        // try to parse any encoding in text
+        if (data->hasText()) {
+            const QString text = data->text();
+            if (activeCoding() == AbstractByteArrayView::CharCodingId) {
+                ByteArrayChar8StringDecoder char8StringDecoder;
+                char8StringDecoder.setCharCodec(charCodingName());
+                int usedTextSize = -1;
+                const ByteArrayChar8StringDecoder::CodeState evalResult = char8StringDecoder.decode(&byteArray, text, 0, -1, &usedTextSize);
+                if ((evalResult != ByteArrayChar8StringDecoder::CodeAcceptable) ||
+                    (usedTextSize != text.size())) {
+                    byteArray.clear();
+                }
+            } else {
+                ByteArrayValueStringDecoder valueStringDecoder(mValueCodec);
+                const ByteArrayValueStringDecoder::CodeState evalResult = valueStringDecoder.decode(&byteArray, text);
+                if (evalResult != ByteArrayValueStringDecoder::CodeAcceptable) {
+                    byteArray.clear();
+                }
+            }
+        }
+        // nothing decoded (for now empty -> failed)? fall back to raw data of first format
+        if (byteArray.isEmpty()) {
+            const QString firstDataFormatName = data->formats()[0];
+            byteArray = data->data(firstDataFormatName);
+        }
     }
 
-    const QByteArray byteArray = data->data(dataFormatName);
-
     if (!byteArray.isEmpty()) {
         insert(byteArray);
     }
