@@ -10,15 +10,18 @@
 #define OKTETA_BYTEARRAYTABLERANGES_HPP
 
 // lib
-#include <okteta/selection.hpp>
-#include <okteta/coordrangelist.hpp>
-#include <okteta/oktetagui_export.hpp>
+#include "oktetagui_export.hpp"
+#include "selection.hpp"
+#include "coordrangelist.hpp"
 // Okteta core
 #include <Okteta/AddressRange>
+// Qt
+#include <QScopedPointer>
 
 namespace Okteta {
 class ArrayChangeMetricsList;
 class ByteArrayTableLayout;
+class ByteArrayTableRangesPrivate;
 
 /** a class to control all the ranges like marking and selections
  * holds also all modified ranges and merges them so a repaint can take its info from here
@@ -30,11 +33,13 @@ class OKTETAGUI_EXPORT ByteArrayTableRanges
 {
 public:
     explicit ByteArrayTableRanges(ByteArrayTableLayout* layout);
-    ByteArrayTableRanges() = delete;
+    ByteArrayTableRanges(const ByteArrayTableRanges&) = delete;
 
     ~ByteArrayTableRanges();
 
-public: // modifcation access
+    ByteArrayTableRanges& operator=(const ByteArrayTableRanges&) = delete;
+
+public: // modification access
     void setMarking(const AddressRange& marking);
     void setSelectionStart(Address startIndex);
     void setSelectionEnd(Address startIndex);
@@ -58,6 +63,7 @@ public: // modifcation access
     void adaptToChanges(const ArrayChangeMetricsList& changeList, Size oldLength);
     void resetChangedRanges();
 
+    void takeHasSelectionChanged(bool* hasSelectionChanged, bool* selectionChanged);
     void setModified(bool M = true);
     /** removes all ranges */
     void reset();
@@ -104,7 +110,8 @@ private:
 
     CoordRangeList ChangedRanges;
 
-    ByteArrayTableLayout* mLayout;
+    const QScopedPointer<ByteArrayTableRangesPrivate> d_ptr;
+    Q_DECLARE_PRIVATE(ByteArrayTableRanges)
 };
 
 inline int ByteArrayTableRanges::noOfSelections()  const { return 1; }
