@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Gui library, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2004, 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2004, 2008, 2025 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -17,6 +17,13 @@ AbstractController::AbstractController(AbstractController* parent)
 
 AbstractController::~AbstractController() = default;
 
+void AbstractController::handleShortcutOverrideEvent(QKeyEvent* keyEvent) const
+{
+    if (mParent) {
+        mParent->handleShortcutOverrideEvent(keyEvent);
+    }
+}
+
 bool AbstractController::handleKeyPress(QKeyEvent* keyEvent)
 {
     return mParent ? mParent->handleKeyPress(keyEvent) : false;
