@@ -21,9 +21,12 @@ protected:
     AbstractMouseController(AbstractByteArrayView* view, AbstractMouseController* parent);
 
 public:
-    AbstractMouseController() = delete;
+    AbstractMouseController(const AbstractMouseController&) = delete;
+
     virtual ~AbstractMouseController();
 
+    AbstractMouseController& operator=(const AbstractMouseController&) = delete;
+
 public: // API to be implemented
     virtual bool handleMousePressEvent(QMouseEvent* mouseEvent);
     virtual bool handleMouseMoveEvent(QMouseEvent* mouseEvent);
