@@ -26,16 +26,6 @@ namespace Okteta {
 
 static constexpr char DropperOctetStreamFormatName[] = "application/octet-stream";
 
-Dropper::Dropper(AbstractByteArrayView* view)
-    : mByteArrayView(view)
-    , mIsActive(false)
-{
-}
-
-Dropper::~Dropper() = default;
-
-bool Dropper::isActive() const { return mIsActive; }
-
 bool Dropper::handleDragEnterEvent(QDragEnterEvent* dragEnterEvent)
 {
     bool eventUsed = false;
