@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Gui library, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2004, 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2004, 2008, 2025 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -24,8 +24,10 @@ private:
     {
         MoveBackward,
         MoveWordBackward,
+        MoveNonZeroBackward,
         MoveForward,
         MoveWordForward,
+        MoveNonZeroForward,
         MoveUp,
         MovePgUp,
         MoveDown,
@@ -36,10 +38,17 @@ private:
         MoveEnd
     };
 
+    enum SelectAction
+    {
+        Unselect,
+        Select,
+    };
+
 public:
     KeyNavigator(AbstractByteArrayView* view, AbstractController* parent);
 
 public: // AbstractController API
+    void handleShortcutOverrideEvent(QKeyEvent* keyEvent) const override;
     bool handleKeyPress(QKeyEvent* keyEvent) override;
 
 public:
@@ -47,7 +56,7 @@ public:
 
 private:
     /** moves the cursor according to the action, handles all drawing */
-    void moveCursor(MoveAction action, bool select);
+    void moveCursor(MoveAction action, SelectAction selectAction);
     void selectAll();
 
 private:
