@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Gui library, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2019 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2019, 2025 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -30,14 +30,33 @@ UndoRedoController::UndoRedoController(AbstractByteArrayView* view, AbstractCont
 
 UndoRedoController::~UndoRedoController() = default;
 
+void UndoRedoController::handleShortcutOverrideEvent(QKeyEvent* keyEvent) const
+{
+    bool isKeyToUse = false;
+
+    if (!mView->isReadOnly()) {
+        if (keyEvent->matches(QKeySequence::Undo) ||
+            keyEvent->matches(QKeySequence::Redo)) {
+            isKeyToUse = true;
+        }
+    }
+
+    if (isKeyToUse) {
+        keyEvent->accept();
+    } else {
+        AbstractController::handleShortcutOverrideEvent(keyEvent);
+    }
+}
+
+
 bool UndoRedoController::handleKeyPress(QKeyEvent* keyEvent)
 {
     bool keyUsed = false;
 
     if (!mView->isReadOnly()) {
-        if (keyEvent == QKeySequence::Undo) {
+        if (keyEvent->matches(QKeySequence::Undo)) {
             keyUsed = undo();
-        } else if (keyEvent == QKeySequence::Redo) {
+        } else if (keyEvent->matches(QKeySequence::Redo)) {
             keyUsed = redo();
         }
     }
