@@ -41,10 +41,10 @@ public:
     /** creates a coord with 0,0 */
     Coord() = default;
     constexpr Coord(LinePosition pos, Line line);
-    Coord(const Coord& other) = default;
-    Coord& operator=(const Coord& other) = default;
+    Coord(const Coord& other) = default; // trivial
+    Coord& operator=(const Coord& other) = default; // trivial
 
-    ~Coord() = default;
+    ~Coord() = default; // trivial
 
 public: // logic
     constexpr bool operator==(const Coord& other) const;
