@@ -23,10 +23,12 @@ class AbstractColumnRendererPrivate
 {
 public:
     explicit AbstractColumnRendererPrivate(AbstractColumnStylist* stylist);
-    AbstractColumnRendererPrivate() = delete;
+    AbstractColumnRendererPrivate(const AbstractColumnRendererPrivate&) = delete;
 
     virtual ~AbstractColumnRendererPrivate();
 
+    AbstractColumnRendererPrivate& operator=(const AbstractColumnRendererPrivate&) = delete;
+
 public:
     void renderBlankLine(QPainter* painter) const;
     void renderEmptyColumn(QPainter* painter, const PixelXRange& xSpan, const PixelYRange& ySpan);
