@@ -35,6 +35,7 @@ public: // AbstractColumnRenderer API
 public:
     void setFormat(OffsetFormat::Format format, const QFontMetrics& fontMetrics);
     void setFontMetrics(const QFontMetrics& fontMetrics);
+    void setMargin(PixelX margin);
 
 private:
     /** recalculates all x values */
@@ -53,6 +54,8 @@ public: // pixel related
     /** */
     PixelY mDigitBaseLine = 0;
 
+    PixelX mMargin = 2;
+
 public: // general layout
     OffsetFormat::Format mFormat;
 
