@@ -34,8 +34,11 @@ public:
 
 public:
     OffsetFormat() = delete;
+    OffsetFormat(const OffsetFormat&) = delete;
     ~OffsetFormat() = delete;
 
+    OffsetFormat& operator=(const OffsetFormat&) = delete;
+
 public:
     /** */
     static unsigned int codingWidth(int i);
