@@ -9,6 +9,7 @@
 #include "labelledtoolbarwidget.hpp"
 
 // Qt
+#include <QStyle>
 #include <QLabel>
 #include <QHBoxLayout>
 
@@ -30,6 +31,15 @@ LabelledToolBarWidget::LabelledToolBarWidget(QLabel* label,
     setLayout(layout);
 }
 
+void LabelledToolBarWidget::setHasLabelMargin(bool hasLabelMargin)
+{
+    const int labelMargin = hasLabelMargin ? style()->pixelMetric(QStyle::PM_ButtonMargin) : 0;
+    const bool isLTR = (parentWidget()->layoutDirection() == Qt::LeftToRight);
+    const int leftMargin = isLTR ? labelMargin : 0;
+    const int rightMargin = isLTR ? 0 : labelMargin;
+    layout()->setContentsMargins(leftMargin, 0, rightMargin, 0);
+}
+
 }
 
 #include "moc_labelledtoolbarwidget.cpp"
