@@ -58,6 +58,11 @@ int BookmarksTool::offsetCoding()            const { return mByteArrayView ? mBy
 
 void BookmarksTool::setTargetModel(AbstractModel* model)
 {
+    ByteArrayView* const byteArrayView = model ? model->findBaseModel<ByteArrayView*>() : nullptr;
+    if (byteArrayView == mByteArrayView) {
+        return;
+    }
+
     const int oldOffsetCoding = offsetCoding();
 
     if (mByteArrayView) {
@@ -67,8 +72,9 @@ void BookmarksTool::setTargetModel(AbstractModel* model)
         mByteArray->disconnect(this);
     }
 
-    mByteArrayView = model ? model->findBaseModel<ByteArrayView*>() : nullptr;
+    mByteArrayView = byteArrayView;
 
+    // TODO; check if already same document used before
     ByteArrayDocument* document =
         mByteArrayView ? qobject_cast<ByteArrayDocument*>(mByteArrayView->baseModel()) : nullptr;
     mByteArray = document ? document->content() : nullptr;
@@ -112,7 +118,7 @@ Okteta::Bookmark BookmarksTool::createBookmark()
     Okteta::Bookmark bookmark;
 
     if (mBookmarks) {
-        const int cursorPosition = mByteArrayView->cursorPosition();
+        const Okteta::Address cursorPosition = mByteArrayView->cursorPosition();
 
         // search for text at cursor
         const Okteta::CharCodec* charCodec = Okteta::CharCodec::createCodec(mByteArrayView->charCodingName());
@@ -179,7 +185,7 @@ void BookmarksTool::onCursorPositionChanged(Okteta::Address newPosition)
 // better just only check for the added and removed, if they include the current position, then change mCanCreateBookmark
 void BookmarksTool::onBookmarksModified()
 {
-    const int cursorPosition = mByteArrayView->cursorPosition();
+    const Okteta::Address cursorPosition = mByteArrayView->cursorPosition();
     onCursorPositionChanged(cursorPosition);
 }
 
