@@ -46,7 +46,7 @@ void ModSum64ByteArrayChecksumAlgorithm::saveConfig(KConfigGroup& configGroup) c
 bool ModSum64ByteArrayChecksumAlgorithm::calculateChecksum(QString* result,
                                                            const Okteta::AbstractByteArrayModel* model, const Okteta::AddressRange& range) const
 {
-    const bool useLittleEndian = (mParameterSet.endianness() == LittleEndian);
+    const bool useLittleEndian = (mParameterSet.endianness() == QSysInfo::LittleEndian);
     quint64 modSum = useLittleEndian ?
                      calculateModSumWithLittleEndian(model, range) :
                      calculateModSumWithBigEndian(model, range);
