@@ -18,12 +18,12 @@ NoByteArrayFilterParameterSetEdit::~NoByteArrayFilterParameterSetEdit() = defaul
 
 void NoByteArrayFilterParameterSetEdit::setValues(const AbstractByteArrayFilterParameterSet* parameterSet)
 {
-    Q_UNUSED(parameterSet);
+    Q_UNUSED(parameterSet)
 }
 
 void NoByteArrayFilterParameterSetEdit::getParameterSet(AbstractByteArrayFilterParameterSet* parameterSet) const
 {
-    Q_UNUSED(parameterSet);
+    Q_UNUSED(parameterSet)
 }
 
 #include "moc_nobytearrayfilterparametersetedit.cpp"
