@@ -13,7 +13,7 @@
 
 QValidator::State SIntSpinBox::validate(QString& input, int& pos) const
 {
-    Q_UNUSED(pos);
+    Q_UNUSED(pos)
 
     QValidator::State result;
 
@@ -39,7 +39,7 @@ QValidator::State SIntSpinBox::validate(QString& input, int& pos) const
 
 void SIntSpinBox::fixup(QString& input) const
 {
-    Q_UNUSED(input);
+    Q_UNUSED(input)
 
     // TODO: what can be done here? remove localized stuff?
 }
