@@ -17,8 +17,13 @@ struct Binary8
 {
 public:
     Binary8(quint8 v);
+    Binary8(const Binary8&) = default;
     Binary8();
 
+    ~Binary8() = default;
+
+    Binary8& operator=(const Binary8&) = default;
+
 public:
     QString toString() const;
 
