@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2009, 2023 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -10,6 +10,7 @@
 #define KASTEN_FLOAT32_HPP
 
 // Qt
+#include <QLocale>
 #include <QMetaType>
 #include <QString>
 
@@ -26,6 +27,7 @@ public:
 
 public:
     QString toString() const;
+    QString toString(const QLocale& locale) const;
 
 public:
     float value = 0;
@@ -39,6 +41,11 @@ inline QString Float32::toString() const
     return QString::number(value, 'e', 8);
 }
 
+inline QString Float32::toString(const QLocale& locale) const
+{
+    return locale.toString(value, 'e', 16);
+}
+
 Q_DECLARE_METATYPE(Float32)
 
 #endif
