@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2009, 2023 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -10,6 +10,7 @@
 #define KASTEN_SINT32_HPP
 
 // Qt
+#include <QLocale>
 #include <QMetaType>
 #include <QString>
 
@@ -26,6 +27,7 @@ public:
 
 public:
     QString toString() const;
+    QString toString(const QLocale& locale) const;
 
 public:
     qint32 value = 0;
@@ -35,6 +37,7 @@ inline SInt32::SInt32() = default;
 inline SInt32::SInt32(qint32 v) : value(v) {}
 
 inline QString SInt32::toString() const { return QString::number(value); }
+inline QString SInt32::toString(const QLocale& locale) const { return locale.toString(value); }
 
 Q_DECLARE_METATYPE(SInt32)
 
