@@ -19,8 +19,12 @@ class AbstractColumnFrameRendererPrivate
 {
 public:
     AbstractColumnFrameRendererPrivate();
+    AbstractColumnFrameRendererPrivate(const AbstractColumnFrameRendererPrivate&) = delete;
+
     ~AbstractColumnFrameRendererPrivate();
 
+    AbstractColumnFrameRendererPrivate& operator=(const AbstractColumnFrameRendererPrivate&) = delete;
+
 public:
     void updateWidths();
 
