@@ -61,12 +61,11 @@ qint64 BasicPrimitiveDataInformation<T, C>::readData(const Okteta::AbstractByteA
                                                      Okteta::Address address, BitCount64 bitsRemaining, quint8* bitOffset)
 {
     Q_ASSERT(mHasBeenUpdated); // update must have been called prior to reading except
-    const bool wasValid = mWasAbleToRead;
     if (bitsRemaining < BitCount64(size())) {
         mWasAbleToRead = false;
         mValue = 0;
 
-        if (wasValid != mWasAbleToRead) {
+        if (mWasAbleToReadBefore != mWasAbleToRead) {
             topLevelDataInformation()->setChildDataChanged();
         }
         return -1;
@@ -78,7 +77,7 @@ qint64 BasicPrimitiveDataInformation<T, C>::readData(const Okteta::AbstractByteA
     // bit offset will always stay the same since type T uses a full number of bytes
     mValue = AllPrimitiveTypes::readValue<T>(input, address, effectiveByteOrder(), *bitOffset);
 
-    if (oldVal != mValue || wasValid != mWasAbleToRead) {
+    if (oldVal != mValue || mWasAbleToReadBefore != mWasAbleToRead) {
         topLevelDataInformation()->setChildDataChanged();
     }
     return size();
