@@ -12,7 +12,7 @@
 
 #include <QScriptValue>
 
-#include "../poddecoder/typeeditors/sintspinbox.hpp"
+#include <view/poddecoder/typeeditors/sintspinbox.hpp>
 #include "../sintdatainformation.hpp"
 
 QString SignedBitfieldDataInformation::valueStringImpl() const
@@ -21,6 +21,22 @@ QString SignedBitfieldDataInformation::valueStringImpl() const
     return SIntDataInformationMethods<qint64>::staticValueString(mValue.value<qint64>());
 }
 
+QVariant SignedBitfieldDataInformation::valueToQVariant() const
+{
+    Q_ASSERT(mWasAbleToRead);
+    return SIntDataInformationMethods<qint64>::staticToQVariant(mValue.value<qint64>());
+}
+
+QString SignedBitfieldDataInformation::valueToQString(AllPrimitiveTypes value) const
+{
+    return SIntDataInformationMethods<qint64>::staticValueString(value.value<qint64>());
+}
+
+QVariant SignedBitfieldDataInformation::valueToQVariant(AllPrimitiveTypes value) const
+{
+    return SIntDataInformationMethods<qint64>::staticToQVariant(value.value<qint64>());
+}
+
 QWidget* SignedBitfieldDataInformation::createEditWidget(QWidget* parent) const
 {
     auto* ret = new SIntSpinBox(parent);
