@@ -11,6 +11,8 @@
 
 #include <Okteta/Address>
 #include "../datainformationbase.hpp"
+// Qt
+#include <QSysInfo>
 
 class StringDataInformation;
 
@@ -25,7 +27,7 @@ public:
     {
         None = 0x0,
         Sequence = 0x1, // termination sequence (i.e. '\0')
-        CharCount = 0x2, // numer of unicode code points
+        CharCount = 0x2, // number of unicode code points
         ByteCount = 0x4, // maximum number of bytes
         SeqOrCharCount = CharCount + Sequence, // whatever comes first
         SeqOrByteCount = ByteCount + Sequence // whatever comes first
@@ -44,12 +46,12 @@ public:
     virtual uint count() const = 0;
     virtual QString charType() const = 0;
     virtual QString stringValue(int row) const = 0;
-    virtual QString completeString(bool skipInvalid = false) const = 0;
+    virtual QString completeString() const = 0;
     virtual BitCount32 size() const = 0;
     virtual BitCount32 sizeAt(uint index) const = 0;
     virtual qint64 read(const Okteta::AbstractByteArrayModel* input, Okteta::Address address, BitCount64 bitsRemaining) = 0;
     /** by default just sets value, if more logic is needed can be overridden */
-    virtual void setLittleEndian(bool littleEndian);
+    virtual void setEndianness(QSysInfo::Endian endianness);
     TerminationMode terminationMode() const;
     void setTerminationMode(TerminationMode mode);
 
