@@ -65,7 +65,7 @@ QString Utf32StringData::stringValue(int row) const
     return i18n("%1 (U+%2)", QString(QChar(mCodePoints.at(row))), number);
 }
 
-QString Utf32StringData::completeString(bool skipInvalid) const
+QString Utf32StringData::completeString() const
 {
     QVarLengthArray<QChar> data(mCodePoints.size() + mNonBMPCount);
     int codePointCount = mCodePoints.size();
@@ -73,10 +73,6 @@ QString Utf32StringData::completeString(bool skipInvalid) const
     for (int idx = 0; idx < codePointCount; ++idx) {
         uint val = mCodePoints.at(idx);
         if (val > UNICODE_MAX) {
-            if (skipInvalid) {
-                continue;
-            }
-
             data[i] = QChar::ReplacementCharacter;
         } else if (val > BMP_MAX) {
             data[i] = QChar::highSurrogate(val);
@@ -91,7 +87,7 @@ QString Utf32StringData::completeString(bool skipInvalid) const
     return QString(data.constData(), i);
 }
 
-qint64 Utf32StringData::read(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
+qint64 Utf32StringData::read(const Okteta::AbstractByteArrayModel* input, Okteta::Address address,
                              BitCount64 bitsRemaining)
 {
     const int oldSize = count();
