@@ -24,7 +24,7 @@ public:
 
     bool isUnion() const override;
     BitCount32 size() const override;
-    qint64 readData(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
+    qint64 readData(const Okteta::AbstractByteArrayModel* input, Okteta::Address address,
                     BitCount64 bitsRemaining, quint8* bitOffset) override;
     BitCount64 childPosition(const DataInformation* child, Okteta::Address start) const override;
 
