@@ -20,11 +20,15 @@ class StructureDefinitionFile;
 
 class AbstractStructureParser
 {
-    Q_DISABLE_COPY(AbstractStructureParser)
-
 public:
     AbstractStructureParser(const QString& pluginName, const QString& absolutePath);
+    AbstractStructureParser(const AbstractStructureParser&) = delete;
+
     virtual ~AbstractStructureParser();
+
+    AbstractStructureParser& operator=(const AbstractStructureParser&) = delete;
+
+public:
     virtual QStringList parseStructureNames() const = 0;
     virtual QVector<TopLevelDataInformation*> parseStructures() const = 0;
 
