@@ -31,7 +31,7 @@ struct CommonParsedData : public ParserInfo
 {
     inline explicit CommonParsedData(const ParserInfo& i)
         : ParserInfo(i)
-        , endianess(DataInformation::DataInformationEndianess::EndianessInherit)
+        , endianness(DataInformation::DataInformationEndianness::EndiannessInherit)
     {}
     CommonParsedData(const CommonParsedData&) = delete;
 
@@ -43,7 +43,7 @@ struct CommonParsedData : public ParserInfo
     QScriptValue validationFunc;
     QScriptValue toStringFunc;
     QString customTypeName;
-    DataInformation::DataInformationEndianess endianess;
+    DataInformation::DataInformationEndianness endianness;
 };
 
 struct BitfieldParsedData : public ParserInfo
