@@ -446,8 +446,8 @@ DataInformation* OsdParser::parseElement(const QDomElement& elem, const OsdParse
         CommonParsedData cpd(info);
         QString byteOrderStr = readProperty(elem, PROPERTY_BYTEORDER());
         if (!byteOrderStr.isEmpty()) {
-            cpd.endianess = ParserUtils::byteOrderFromString(byteOrderStr,
-                                                             LoggerWithContext(info.logger, info.context()));
+            cpd.endianness = ParserUtils::byteOrderFromString(byteOrderStr,
+                                                              LoggerWithContext(info.logger, info.context()));
         }
         cpd.updateFunc = ParserUtils::functionSafeEval(info.engine, readProperty(elem, PROPERTY_UPDATE_FUNC()));
         cpd.validationFunc = ParserUtils::functionSafeEval(info.engine, readProperty(elem, PROPERTY_VALIDATION_FUNC()));
