@@ -13,7 +13,8 @@
 
 #include <QPushButton>
 #include <QLabel>
-#include <QLayout>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
 
@@ -27,16 +28,10 @@ StructureAddRemoveWidget::StructureAddRemoveWidget(const QStringList& selected,
     : QWidget(parent)
     , mTool(tool)
 {
-    QHBoxLayout* baseLayout;
-    QVBoxLayout* tree1Layout;
-    QVBoxLayout* tree2Layout;
-    QVBoxLayout* leftRightLayout;
-    QVBoxLayout* upDownLayout;
-
-    baseLayout = new QHBoxLayout();
+    auto* baseLayout = new QHBoxLayout();
     baseLayout->setContentsMargins(0, 0, 0, 0);
 
-    tree1Layout = new QVBoxLayout();
+    auto* tree1Layout = new QVBoxLayout();
     mTree1Label = new QLabel(i18nc("@info:label", "Installed structures:"), this);
     tree1Layout->addWidget(mTree1Label);
     mTreeAvailable = new QTreeWidget(this);
@@ -46,7 +41,7 @@ StructureAddRemoveWidget::StructureAddRemoveWidget(const QStringList& selected,
     mTreeAvailable->setColumnHidden(1, true);
     tree1Layout->addWidget(mTreeAvailable);
 
-    tree2Layout = new QVBoxLayout();
+    auto* tree2Layout = new QVBoxLayout();
     mTree2Label = new QLabel(i18nc("@info:label", "Used structures:"), this);
     tree2Layout->addWidget(mTree2Label);
     mTreeSelected = new QTreeWidget(this);
@@ -56,7 +51,7 @@ StructureAddRemoveWidget::StructureAddRemoveWidget(const QStringList& selected,
     mTreeSelected->setColumnHidden(1, true);
     tree2Layout->addWidget(mTreeSelected);
 
-    leftRightLayout = new QVBoxLayout();
+    auto* leftRightLayout = new QVBoxLayout();
     leftRightLayout->addStretch();
     mRightButton = new QPushButton(QIcon::fromTheme(QStringLiteral("arrow-right")), QString(), this);
     leftRightLayout->addWidget(mRightButton);
@@ -64,7 +59,7 @@ StructureAddRemoveWidget::StructureAddRemoveWidget(const QStringList& selected,
     leftRightLayout->addWidget(mLeftButton);
     leftRightLayout->addStretch();
 
-    upDownLayout = new QVBoxLayout();
+    auto* upDownLayout = new QVBoxLayout();
     upDownLayout->addStretch();
     mUpButton = new QPushButton(QIcon::fromTheme(QStringLiteral("arrow-up")), QString(), this);
     upDownLayout->addWidget(mUpButton);
@@ -101,16 +96,16 @@ StructureAddRemoveWidget::StructureAddRemoveWidget(const QStringList& selected,
                     }
                     for (int i = 0; i < avail->childCount(); i++) {
                         QTreeWidgetItem* selStruct = avail->child(i);
-                        QTreeWidgetItem* item = new QTreeWidgetItem(mTreeSelected,
-                                                                    QStringList { selStruct->text(0), pluginName });
+                        auto* item = new QTreeWidgetItem(mTreeSelected,
+                                                         QStringList { selStruct->text(0), pluginName });
                         mTreeSelected->addTopLevelItem(item);
                     }
 
                     break;
                 }
             } else {
-                QTreeWidgetItem* item = new QTreeWidgetItem(mTreeSelected,
-                                                            QStringList { structName, pluginName });
+                auto* item = new QTreeWidgetItem(mTreeSelected,
+                                                 QStringList { structName, pluginName });
                 mTreeSelected->addTopLevelItem(item);
             }
         }
@@ -138,12 +133,12 @@ void StructureAddRemoveWidget::buildAvailableList()
         if (!def->pluginInfo().isPluginEnabled()) {
             continue;
         }
-        QTreeWidgetItem* item = new QTreeWidgetItem(mTreeAvailable,
-                                                    QStringList { def->pluginInfo().pluginName(), pluginName });
+        auto* item = new QTreeWidgetItem(mTreeAvailable,
+                                         QStringList { def->pluginInfo().pluginName(), pluginName });
         const auto structureNames = def->structureNames();
         for (const QString& name : structureNames) {
-            QTreeWidgetItem* subItem = new QTreeWidgetItem(item,
-                                                           QStringList { name, pluginName });
+            auto* subItem = new QTreeWidgetItem(item,
+                                                QStringList { name, pluginName });
             item->addChild(subItem);
         }
 
@@ -177,8 +172,8 @@ void StructureAddRemoveWidget::moveRight()
         if (!item->parent()) {
             continue;     // maybe sometime add all subitems
         }
-        QTreeWidgetItem* moveOver = new QTreeWidgetItem(mTreeSelected,
-                                                        QStringList { item->text(0), item->text(1) });
+        auto* moveOver = new QTreeWidgetItem(mTreeSelected,
+                                             QStringList { item->text(0), item->text(1) });
         // item name then parent name then path
         mTreeSelected->addTopLevelItem(moveOver);
         changed = true;
