@@ -32,7 +32,7 @@ namespace Kasten {
 
 StructuresTool::StructuresTool()
     : mByteOrder(StructureViewPreferences::byteOrder())
-    , mManager(new StructuresManager(this))
+    , mManager(new StructuresManager())
     , mWritingData(false)
     , mCurrentItemDataChanged(false)
     , mIsStructureMarked(false)
