@@ -40,6 +40,7 @@ ViewProfileController::ViewProfileController(ByteArrayViewProfileManager* viewPr
 #else
     mViewProfileActionMenu->setDelayed(false);
 #endif
+    mViewProfileActionMenu->setEnabled(false);
 
     mCreateNewAction =
         new QAction(QIcon::fromTheme(QStringLiteral("document-new")),
@@ -47,6 +48,7 @@ ViewProfileController::ViewProfileController(ByteArrayViewProfileManager* viewPr
                           "Create New..."),
                     this);
     connect(mCreateNewAction, &QAction::triggered, this, &ViewProfileController::onCreateNewActionTriggered);
+    mCreateNewAction->setEnabled(false);
 
     mSaveChangesAction =
         new QAction(QIcon::fromTheme(QStringLiteral("document-save")),
@@ -54,6 +56,7 @@ ViewProfileController::ViewProfileController(ByteArrayViewProfileManager* viewPr
                           "Save Changes"),
                     this);
     connect(mSaveChangesAction, &QAction::triggered, this, &ViewProfileController::onSaveChangesActionTriggered);
+    mSaveChangesAction->setEnabled(false);
 
     mResetChangesAction =
         new QAction(QIcon::fromTheme(QStringLiteral("document-revert")),
@@ -61,6 +64,7 @@ ViewProfileController::ViewProfileController(ByteArrayViewProfileManager* viewPr
                           "Reset Changes"),
                     this);
     connect(mResetChangesAction, &QAction::triggered, this, &ViewProfileController::onResetChangesActionTriggered);
+    mResetChangesAction->setEnabled(false);
 
     mViewProfileActionMenu->addAction(mCreateNewAction);
     mViewProfileActionMenu->addSeparator();
@@ -80,8 +84,6 @@ ViewProfileController::ViewProfileController(ByteArrayViewProfileManager* viewPr
             this, &ViewProfileController::onViewProfilesChanged);
 
     onViewProfilesChanged();
-
-    setTargetModel(nullptr);
 }
 
 void ViewProfileController::setTargetModel(AbstractModel* model)
