@@ -10,7 +10,7 @@
 #define KASTEN_BYTEARRAYSTREAMENCODERCONFIGEDITORFACTORYFACTORY_HPP
 
 // lib
-#include <kasten/okteta/oktetakastengui_export.hpp>
+#include "oktetakastengui_export.hpp"
 
 template <class T> class QVector;
 
@@ -21,6 +21,9 @@ class OKTETAKASTENGUI_EXPORT ByteArrayStreamEncoderConfigEditorFactoryFactory
 {
 public:
     ByteArrayStreamEncoderConfigEditorFactoryFactory() = delete;
+    ByteArrayStreamEncoderConfigEditorFactoryFactory(const ByteArrayStreamEncoderConfigEditorFactoryFactory&) = delete;
+
+    ByteArrayStreamEncoderConfigEditorFactoryFactory& operator=(const ByteArrayStreamEncoderConfigEditorFactoryFactory&) = delete;
 
 public:
     static QVector<AbstractModelStreamEncoderConfigEditorFactory*> createFactorys();
