@@ -160,7 +160,7 @@ bool ByteArrayBase32StreamEncoder::encodeDataToStream(QIODevice* device,
                                                       const Okteta::AbstractByteArrayModel* byteArrayModel,
                                                       const Okteta::AddressRange& range)
 {
-    Q_UNUSED(byteArrayView);
+    Q_UNUSED(byteArrayView)
 
     bool success = true;
 
