@@ -48,7 +48,7 @@ bool ByteArrayBase64StreamEncoder::encodeDataToStream(QIODevice* device,
                                                       const Okteta::AbstractByteArrayModel* byteArrayModel,
                                                       const Okteta::AddressRange& range)
 {
-    Q_UNUSED(byteArrayView);
+    Q_UNUSED(byteArrayView)
 
     bool success = true;
 
