@@ -44,12 +44,15 @@ void ByteArrayJanusView::setViewModus(int viewModus)
 
     const bool hasFocus = mView ? mView->hasFocus() : false;
     if (mView) {
+        // start by preparing content constraints, for view settings which depend on those
+        // avoids potential scrollbar flickering on resze after show
+        newView->resize(mView->size());
         newView->setFont(mView->font());
 
         newView->setByteArrayModel(mView->byteArrayModel());
         newView->setReadOnly(mView->isReadOnly());
         newView->setOverwriteMode(mView->isOverwriteMode());
-        newView->setZoomLevel(mView->zoomLevel());
+        newView->setZoomScale(mView->zoomScale());
         newView->setShowsNonprinting(mView->showsNonprinting());
         newView->setValueCoding(mView->valueCoding());
         newView->setCharCoding(mView->charCodingName());
@@ -102,7 +105,8 @@ void ByteArrayJanusView::setViewModus(int viewModus)
     connect(mView, &AbstractByteArrayView::substituteCharChanged, this, &ByteArrayJanusView::substituteCharChanged);
     connect(mView, &AbstractByteArrayView::undefinedCharChanged, this, &ByteArrayJanusView::undefinedCharChanged);
     connect(mView, &AbstractByteArrayView::noOfGroupedBytesChanged, this, &ByteArrayJanusView::noOfGroupedBytesChanged);
-    connect(mView, &AbstractByteArrayView::zoomLevelChanged, this, &ByteArrayJanusView::zoomLevelChanged);
+    connect(mView, &AbstractByteArrayView::zoomLevelChanged, this, &ByteArrayJanusView::zoomScaleChanged);
+    connect(mView, &AbstractByteArrayView::zoomLevelsChanged, this, &ByteArrayJanusView::zoomLevelsChanged);
 
     emit viewModusChanged(mViewModus);
 }
@@ -110,14 +114,34 @@ void ByteArrayJanusView::setViewModus(int viewModus)
 bool ByteArrayJanusView::isReadOnly()             const { return mView->isReadOnly(); }
 void ByteArrayJanusView::setReadOnly(bool isReadOnly) { mView->setReadOnly(isReadOnly); }
 
-void ByteArrayJanusView::setZoomLevel(double Level)
+void ByteArrayJanusView::setZoomScale(double zoomScale)
 {
-    mView->setZoomLevel(Level);
+    mView->setZoomScale(zoomScale);
 }
 
-double ByteArrayJanusView::zoomLevel() const
+double ByteArrayJanusView::zoomScale() const
 {
-    return mView->zoomLevel();
+    return mView->zoomScale();
+}
+
+int ByteArrayJanusView::zoomInLevelsSize() const
+{
+    return mView->zoomInLevelsSize();
+}
+
+int ByteArrayJanusView::zoomOutLevelsSize() const
+{
+    return mView->zoomOutLevelsSize();
+}
+
+double ByteArrayJanusView::zoomScaleForLevel(int zoomLevel) const
+{
+    return mView->zoomScaleForLevel(zoomLevel);
+}
+
+int ByteArrayJanusView::zoomLevelForScale(double zoomScale) const
+{
+    return mView->zoomLevelForScale(zoomScale);
 }
 
 void ByteArrayJanusView::selectAll(bool selectAll)
