@@ -15,6 +15,9 @@
 #include <QRect>
 
 class QPrinter;
+
+namespace FramesPrint {
+
 class AbstractFrameRenderer;
 
 class FramesToPaperPrinter : public QObject
@@ -49,4 +52,6 @@ private:
     QMargins mPageMargins;
 };
 
+}
+
 #endif
