@@ -10,7 +10,7 @@
 #define KASTEN_CREATORCONTROLLERFACTORY_HPP
 
 // lib
-#include <kasten/kastencontrollers_export.hpp>
+#include "kastencontrollers_export.hpp"
 // Kasten core
 #include <Kasten/AbstractXmlGuiControllerFactory>
 
@@ -24,8 +24,12 @@ class KASTENCONTROLLERS_EXPORT CreatorControllerFactory : public AbstractXmlGuiC
 public:
     explicit CreatorControllerFactory(ModelCodecManager* modelCodecManager,
                                       AbstractDocumentStrategy* documentStrategy);
+    CreatorControllerFactory(const CreatorControllerFactory&) = delete;
+
     ~CreatorControllerFactory() override;
 
+    CreatorControllerFactory& operator=(const CreatorControllerFactory&) = delete;
+
 public: // AbstractXmlGuiControllerFactory API
     AbstractXmlGuiController* create(KXMLGUIClient* guiClient) const override;
 
