@@ -10,7 +10,7 @@
 #define KASTEN_COPYASCONTROLLERFACTORY_HPP
 
 // lib
-#include <kasten/kastencontrollers_export.hpp>
+#include "kastencontrollers_export.hpp"
 // Kasten core
 #include <Kasten/AbstractXmlGuiControllerFactory>
 
@@ -24,8 +24,12 @@ class KASTENCONTROLLERS_EXPORT CopyAsControllerFactory : public AbstractXmlGuiCo
 public:
     explicit CopyAsControllerFactory(ModelCodecViewManager* modelCodecViewManager,
                                      ModelCodecManager* modelCodecManager);
+    CopyAsControllerFactory(const CopyAsControllerFactory&) = delete;
+
     ~CopyAsControllerFactory() override;
 
+    CopyAsControllerFactory& operator=(const CopyAsControllerFactory&) = delete;
+
 public: // AbstractXmlGuiControllerFactory API
     AbstractXmlGuiController* create(KXMLGUIClient* guiClient) const override;
 
