@@ -23,13 +23,13 @@ namespace Kasten {
 SelectController::SelectController(KXMLGUIClient* guiClient)
 {
     mSelectAllAction = KStandardAction::selectAll(this, &SelectController::selectAll, this);
+    mSelectAllAction->setEnabled(false);
     mDeselectAction =  KStandardAction::deselect( this, &SelectController::unselect,  this);
+    mDeselectAction->setEnabled(false);
 
     KActionCollection* actionCollection = guiClient->actionCollection();
     actionCollection->addAction(mSelectAllAction->objectName(), mSelectAllAction);
     actionCollection->addAction(mDeselectAction->objectName(), mDeselectAction);
-
-    setTargetModel(nullptr);
 }
 
 void SelectController::setTargetModel(AbstractModel* model)
