@@ -17,9 +17,12 @@ class AbstractModelPrivate
 {
 public:
     explicit AbstractModelPrivate(AbstractModel* parent, AbstractModel* baseModel = nullptr);
+    AbstractModelPrivate(const AbstractModelPrivate&) = delete;
 
     virtual ~AbstractModelPrivate();
 
+    AbstractModelPrivate& operator=(const AbstractModelPrivate&) = delete;
+
 public:
     AbstractModel* baseModel() const;
 
