@@ -22,8 +22,11 @@ protected:
     AbstractModelSelection();
 
 public:
+    AbstractModelSelection(const AbstractModelSelection&) = delete;
     virtual ~AbstractModelSelection();
 
+    AbstractModelSelection& operator=(const AbstractModelSelection&) = delete;
+
 public: // API to be implemented
 //     virtual bool isValid() const = 0;
 
