@@ -36,18 +36,22 @@ void AbstractFileSystemSyncFromRemoteJobPrivate::syncFromRemote()
     } else {
         QTemporaryFile tmpFile;
         tmpFile.setAutoRemove(false);
-        tmpFile.open();
+        isWorkFileOk = tmpFile.open();
 
         mWorkFilePath = tmpFile.fileName();
         mTempFilePath = mWorkFilePath;
 
-        KIO::FileCopyJob* fileCopyJob =
-            KIO::file_copy(url, QUrl::fromLocalFile(mWorkFilePath), -1, KIO::Overwrite);
-        KJobWidgets::setWindow(fileCopyJob, /*mWidget*/ nullptr);
-
-        isWorkFileOk = fileCopyJob->exec();
         if (!isWorkFileOk) {
-            q->setErrorText(fileCopyJob->errorString());
+            q->setErrorText(tmpFile.errorString());
+        } else {
+            KIO::FileCopyJob* fileCopyJob =
+                KIO::file_copy(url, QUrl::fromLocalFile(mWorkFilePath), -1, KIO::Overwrite);
+            KJobWidgets::setWindow(fileCopyJob, /*mWidget*/ nullptr);
+
+            isWorkFileOk = fileCopyJob->exec();
+            if (!isWorkFileOk) {
+                q->setErrorText(fileCopyJob->errorString());
+            }
         }
     }
 
