@@ -10,11 +10,7 @@
 
 // lib
 #include "testdocument.hpp"
-// KF
-#include <KLocalizedString>
 // Qt
-#include <QUrl>
-#include <QByteArray>
 #include <QDataStream>
 #include <QFile>
 #include <QCoreApplication>
