@@ -16,7 +16,7 @@ ToggleButtonPrivate::ToggleButtonPrivate(ToggleButton* parent) : p(parent)
     p->setCheckable(true);
     p->setAutoRaise(true);
     QObject::connect(p, &QAbstractButton::toggled,
-                     p, [&](bool checked) { onToggled(checked); });
+                     p, [this](bool checked) { onToggled(checked); });
 }
 
 void ToggleButtonPrivate::setOtherState(const QIcon& icon, const QString& text, const QString& toolTip)
