@@ -21,6 +21,11 @@ class ToggleButtonPrivate
 {
 public:
     explicit ToggleButtonPrivate(ToggleButton* parent);
+    ToggleButtonPrivate(const ToggleButtonPrivate&) = delete;
+
+    ~ToggleButtonPrivate() = default;
+
+    ToggleButtonPrivate& operator=(const ToggleButtonPrivate&) = delete;
 
 public:
     void setOtherState(const QIcon& icon, const QString& text, const QString& toolTip);
