@@ -9,9 +9,6 @@
 #include "abstractviewarea.hpp"
 #include "abstractviewarea_p.hpp"
 
-// Qt
-#include <Qt>
-
 namespace Kasten {
 
 AbstractViewArea::AbstractViewArea()
