@@ -10,8 +10,11 @@
 #define OKTETAPARTFACTORY_HPP
 
 // KF
-#include <KAboutData>
+#include <kparts_version.h>
 #include <KPluginFactory>
+#if KPARTS_VERSION < QT_VERSION_CHECK(5, 77, 0)
+#include <KAboutData>
+#endif
 
 namespace Kasten {
 class ByteArrayViewProfileManager;
@@ -42,7 +45,9 @@ public: // KPluginFactory API
                     const QString& keyword) override;
 
 private:
+#if KPARTS_VERSION < QT_VERSION_CHECK(5, 77, 0)
     KAboutData mAboutData;
+#endif
     Kasten::ByteArrayViewProfileManager* mByteArrayViewProfileManager;
     Kasten::ModelCodecViewManager* mModelCodecViewManager;
     Kasten::ModelCodecManager* mModelCodecManager;
